@@ -1,16 +1,17 @@
 from __future__ import annotations
-from typing import Any
+import warnings
 from itertools import chain
 
 import numpy as np
 import torch
-from pelutils import log
-from transformers import AutoTokenizer, PreTrainedTokenizerFast
+from transformers import PreTrainedTokenizerFast
 
 from daluke.data import Words, Entities, Example, BatchedExamples, get_special_ids
 from daluke.pretrain.data import MaskedBatchedExamples, ENTITY_UNK_TOKEN
 from daluke.ner.data import NERBatchedExamples, NERDataset, Split, Sequences
+from daluke.api.automodels import AutoDaLUKE
 
+DEFAULT_NER_BATCHSIZE = 8
 
 def get_subword_ids(text: str, tokenizer: PreTrainedTokenizerFast) -> list[list[int]]:
     """
@@ -21,7 +22,11 @@ def get_subword_ids(text: str, tokenizer: PreTrainedTokenizerFast) -> list[list[
 def get_word_id_tensor(subword_ids: list[list[int]]) -> torch.IntTensor:
     return torch.IntTensor(list(chain(*subword_ids)))
 
-def get_entity_id_tensor(text: str, entity_spans: list[tuple[int, int]], entity_vocab: dict[str, dict[str, int]]) -> torch.IntTensor:
+def get_entity_id_tensor(
+    text: str,
+    entity_spans: list[tuple[int, int]],
+    entity_vocab: dict[str, dict[str, int]],
+) -> torch.IntTensor:
     """ Maps the given entities to an id in the entity vocab """
     words = text.split()
     ids = list()
@@ -39,7 +44,7 @@ def get_entity_id_tensor(text: str, entity_spans: list[tuple[int, int]], entity_
             entity_vocab.get(entity, entity_vocab[ENTITY_UNK_TOKEN])["id"]
         )
         if ids[-1] == entity_vocab[ENTITY_UNK_TOKEN]["id"]:
-            log.warning("Unknown entity '%s'. Was your span correct?" % entity)
+            warnings.warn("Unknown entity '%s'. Was your span correct?" % entity)
     return torch.IntTensor(ids)
 
 def get_entity_subword_spans(subword_ids: list[list[int]], entity_spans:list[tuple[int, int]]) -> list[tuple[int, int]]:
@@ -52,25 +57,23 @@ def get_entity_subword_spans(subword_ids: list[list[int]], entity_spans:list[tup
 def example_from_str(
         text:             str,
         entity_spans:     list[tuple[int, int]],
-        entity_vocab:     dict[str, dict[str, int]],
-        metadata:         dict[str, Any],
+        daluke:           AutoDaLUKE
     ) -> BatchedExamples:
-    tokenizer = AutoTokenizer.from_pretrained(metadata["base-model"])
-    subword_ids = get_subword_ids(text, tokenizer)
-    sep, cls_, pad = get_special_ids(tokenizer)
+    subword_ids = get_subword_ids(text, daluke.tokenizer)
+    sep, cls_, pad = get_special_ids(daluke.tokenizer)
 
     w = Words.build(
         ids     = get_word_id_tensor(subword_ids),
-        max_len = metadata["max-seq-length"],
+        max_len = daluke.metadata["max-seq-length"],
         sep_id  = sep,
         cls_id  = cls_,
         pad_id  = pad,
     )
     e = Entities.build(
-        ids             = get_entity_id_tensor(text, entity_spans, entity_vocab),
+        ids             = get_entity_id_tensor(text, entity_spans, daluke.entity_vocab),
         spans           = get_entity_subword_spans(subword_ids, entity_spans),
-        max_entities    = metadata["max-entities"],
-        max_entity_span = metadata["max-entity-span"],
+        max_entities    = daluke.metadata["max-entities"],
+        max_entity_span = daluke.metadata["max-entity-span"],
     )
     return BatchedExamples.build([
             Example(
@@ -84,14 +87,12 @@ def example_from_str(
 def masked_example_from_str(
         text:             str,
         entity_spans:     list[tuple[int, int]],
-        entity_vocab:     dict[str, dict[str, int]],
-        metadata:         dict[str, Any],
+        daluke:           AutoDaLUKE
     ) -> MaskedBatchedExamples:
     batched_examples = example_from_str(
-        text, entity_spans, entity_vocab, metadata,
+        text, entity_spans, daluke,
     )
-    tokenizer = AutoTokenizer.from_pretrained(metadata["base-model"])
-    mask_token = tokenizer.convert_tokens_to_ids(tokenizer.mask_token)
+    mask_token = daluke.tokenizer.convert_tokens_to_ids(daluke.tokenizer.mask_token)
     wordmask = torch.zeros_like(batched_examples.words.ids, dtype=torch.bool, device=batched_examples.words.ids.device)
     wordmask[batched_examples.words.ids == mask_token] = True
 
@@ -112,29 +113,27 @@ class SingletonNERData(NERDataset):
     labels = ("LOC", "PER", "ORG", "MISC")
     all_labels = (null_label,) + labels
 
-    def load(self, text: str, **_):
-        words = text.split()
+    def load(self, texts: list[str], **_):
+        word_texts = [text.split() for text in texts]
         self.data[Split.TEST] = Sequences(
-            texts               = [words],
-            annotations         = [[self.null_label for _ in range(len(words))]],
-            sentence_boundaries = [[len(words)]]
+            texts               = word_texts,
+            annotations         = [[self.null_label for _ in range(len(words))] for words in word_texts],
+            sentence_boundaries = [[len(words)] for words in word_texts],
         )
         self.loaded = True
 
-def ner_example_from_str(
-        text:       str,
-        metadata:   dict[str, Any],
-    ) -> NERBatchedExamples:
-    """
-
-    """
+def ner_examples_from_str(
+        texts:     list[str],
+        daluke:    AutoDaLUKE,
+        batch_size: int=DEFAULT_NER_BATCHSIZE,
+    ) -> list[NERBatchedExamples]:
     data = SingletonNERData(
-        base_model      = metadata["base-model"],
-        max_seq_length  = metadata["max-seq-length"],
-        max_entities    = metadata["max-entities"],
-        max_entity_span = metadata["max-entity-span"],
-        device          = torch.device("cuda" if torch.cuda.is_available() else "cpu"),
+        base_model      = daluke.metadata["base-model"],
+        max_seq_length  = daluke.metadata["max-seq-length"],
+        max_entities    = daluke.metadata["max-entities"],
+        max_entity_span = daluke.metadata["max-entity-span"],
+        device          = torch.device("cuda:0" if torch.cuda.is_available() else "cpu"),
     )
-    data.load(text)
-    # Extract example from singleton dataloader
-    return next(iter(data.build(Split.TEST, 8)))
+    data.load(texts)
+    # Extract examples from dataloader
+    return list(data.build(Split.TEST, batch_size))
